# sekg
this is library for software engineering knowledge graph.

## description
1. including wrapper for neo4j by py2neo.
2. the preprocess tool for stack overflow html.
3. graph2vec library
...
todo

## support
python 2.7 / 3.5
